
-- Make sure redo log data has supplemental logging enabled
-- This provides before images and PK information in the LCR
-- Can be set on database or table level
alter database add supplemental log data;

select * from flashback_transaction_query where logon_user = 'DMANN' and COMMIT_TIMESTAMP > (SYSDATE-10/1440)
ORDER BY XID, undo_change#;

drop table emp;
drop table dept;

CREATE TABLE emp 
   (empno number primary key, empname varchar2(16), salary number);
INSERT INTO emp VALUES (111, 'Mike', 10000);
INSERT INTO emp VALUES (222, 'Dave', 20000);
COMMIT;

CREATE TABLE dept (deptno number, deptname varchar2(32));
INSERT INTO dept VALUES (10, 'Accounting');
COMMIT;

UPDATE emp SET salary = salary + 100 where empno = 111;
INSERT INTO dept VALUES (20, 'Finance'); 
DELETE FROM emp WHERE empno = 111;
COMMIT;

INSERT INTO emp VALUES (111, 'Tom', 50000);
UPDATE emp SET salary = salary + 100 WHERE empno = 111;
UPDATE emp SET salary = salary + 50 WHERE empno = 111;
COMMIT;

-- Show details about User 111's Name/Salary data change history
SELECT versions_xid XID, versions_startscn START_SCN,
  versions_endscn END_SCN, versions_operation OPERATION,
  EMP.* FROM emp
VERSIONS BETWEEN SCN MINVALUE AND MAXVALUE
  where empno = 111;

SELECT xid,
  start_scn,
  commit_scn,
  operation,
  logon_user,
  undo_sql
FROM flashback_transaction_query
WHERE xid = HEXTORAW('06001B00CE060000');

select * from flashback_transaction_query;

select * from flashback_transaction_query where undo_sql is not null and logon_user NOT IN ('SYS');

-- References:
-- http://docs.oracle.com/cd/B12037_01/appdev.101/b10795/adfns_fl.htm#1006764
